abacusai.external_invite — AbacusAI documentation

# abacusai.external_invite

## Classes

`ExternalInvite` | The response of the invites for different emails

## Module Contents

class abacusai.external_invite.ExternalInvite(client, userAlreadyInOrg=None, userAlreadyInAppGroup=None, userExistsAsInternal=None, successfulInvites=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  The response of the invites for different emails

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - userAlreadyInOrg (list) – List of user emails not successfullt invited, because they are already in the organization.

    - userAlreadyInAppGroup (list) – List of user emails not successfully invited, because they are already in the application group.

    - userExistsAsInternal (list) – List of user emails not successfully invited, because they are already internal users.

    - successfulInvites (list) – List of users successfully invited.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict